==> css_debuger-8.x-1.4.tar.gz: css_debuger/js/css_debuger.js <==
/**
 * @file
 * Defines Javascript behaviors for the css debuger module
 */

(function ($, Drupal, drupalSettings) {
  'use strict';

  Drupal.behaviors.css_debugger = {
    attach: function attach() {
      const colorize = function(a) {
        // Supply a valid selector (e.g '*' for wildcard)
        [].forEach.call(
          // Treat Nodelist as an Array (fewer bytes than Array.prototype.forEach.call(...);)
          // Gets the prototype of Array & uses call to execute the function on the NodeList.
          document.querySelectorAll(a), // Query DOM for elements matching the supplied selector
          // (For 110 bytes, use $$() as Chrome, Safari & FF expose it in DevTools)
          (b) => {
            b.style.outline = '1px solid #'(
              // Set the selector outline
              ~~(Math.random() * (1 << 24)),
            ) // Pick a valid random CSS hex color
              .toString(16);
          }
        ); // Convert to a base 16 number. BOOM.
      };

      const decolorize = function(a) {
        // Supply a valid selector (e.g '*' for wildcard)
        [].forEach.call(
          // Treat Nodelist as an Array (fewer bytes than Array.prototype.forEach.call(...);)
          // Gets the prototype of Array & uses call to execute the function on the NodeList.
          document.querySelectorAll(a), // Query DOM for elements matching the supplied selector
          // (For 110 bytes, use $$() as Chrome, Safari & FF expose it in DevTools)
          (b) => {
            b.style.outline = 'none';
          }
        );
      };

      let status = false;
      $(document).keydown(event => {
        // Show the form with alt + C. Use 2 keycodes as 'C' can be uppercase or lowercase.
        // 67/207 = c/C
        if (
          event.altKey === true
          && (event.keyCode === 67 || event.keyCode === 207)
        ) {
          if (status === false) {
            colorize('*');
            status = true;
          } else if (status) {
            decolorize('*');
            status = false;
          }
        }
      });
    }
  };
})(jQuery, Drupal, drupalSettings);

==> css_debuger-8.x-1.5.tar.gz: css_debuger/js/css_debuger.js <==
/**
 * @file
 * Defines Javascript behaviors for the css debuger module
 */

(function($, Drupal, drupalSettings) {
  Drupal.behaviors.css_debugger = {
    attach: function attach() {
      const colorize = function(a) {
        // Supply a valid selector (e.g '*' for wildcard)
        [].forEach.call(
          // Treat Nodelist as an Array (fewer bytes than Array.prototype.forEach.call(...);)
          // Gets the prototype of Array & uses call to execute the function on the NodeList.
          document.querySelectorAll(a), // Query DOM for elements matching the supplied selector
          // (For 110 bytes, use $$() as Chrome, Safari & FF expose it in DevTools)
          b => {
            b.style.outline = "1px solid #"(
              // Set the selector outline
              ~~(Math.random() * (1 << 24))
            ) // Pick a valid random CSS hex color
              .toString(16);
          }
        ); // Convert to a base 16 number. BOOM.
      };

      const decolorize = function(a) {
        // Supply a valid selector (e.g '*' for wildcard)
        [].forEach.call(
          // Treat Nodelist as an Array (fewer bytes than Array.prototype.forEach.call(...);)
          // Gets the prototype of Array & uses call to execute the function on the NodeList.
          document.querySelectorAll(a), // Query DOM for elements matching the supplied selector
          // (For 110 bytes, use $$() as Chrome, Safari & FF expose it in DevTools)
          b => {
            b.style.outline = "none";
          }
        );
      };

      let status = false;
      $(document).keydown(event => {
        // Show the form with alt + C. Use 2 keycodes as 'C' can be uppercase or lowercase.
        // 67/207 = c/C
        if (
          event.altKey === true &&
          (event.keyCode === 67 || event.keyCode === 207)
        ) {
          if (status === false) {
            colorize("*");
            status = true;
          } else if (status) {
            decolorize("*");
            status = false;
          }
        }
      });
    }
  };
})(jQuery, Drupal, drupalSettings);
